@@ -3,7 +3,6 @@ from robot.libraries.BuiltIn import BuiltIn
 from robot.api.deco import keyword
 from robot.api import logger
 from .attribute import AttributeHelper
-from .checkbox import CheckboxHelper
 from .click import ClickHelper
 from .frame import FrameHelper
 from .input import InputHelper
@@ -11,20 +10,19 @@ from .select import SelectHelper
 from .textarea import TextareaHelper
 from .title import TitleHelper
 from .wait import WaitHelper
-from .xpath import XpathHelper
-from .text import TextHelper
 from .text import TextHelper
 from .link import LinkHelper
 from .button import ButtonHelper
 from .webelement import WebElementHelper
 from .util import Util
 
-class SeleniumHelperLibrary(AttributeHelper, CheckboxHelper, ClickHelper,
+class SeleniumHelperLibrary(AttributeHelper, ClickHelper,
  FrameHelper, InputHelper, SelectHelper, TextareaHelper, TitleHelper, WaitHelper,
- XpathHelper, LinkHelper, ButtonHelper, WebElementHelper, TextHelper):
+ LinkHelper, ButtonHelper, WebElementHelper, TextHelper):
 
     """
-    Core principal of helper library to achieve synchronization before performing any action on ``WebElement``
+    Core Principal:
+      Achieve synchronization before performing any action on ``WebElement``
 
     Every ``Keyword`` consist following steps
         - Wait For WebElement
@@ -41,12 +39,19 @@ class SeleniumHelperLibrary(AttributeHelper, CheckboxHelper, ClickHelper,
 
     @keyword("Scroll By Coordinates")
     def scroll_by_coordinates(self, x, y):
+        """
+        Perform scroll in webpage based on co-ordinates
+        """
         self.sellib = BuiltIn().get_library_instance('SeleniumLibrary')
         js = "window.scroll({x},{y})".format(x=x, y=y)
         self.sellib.execute_javascript(js)
 
     @keyword("Should Contain With Screenshot")
     def should_contain_with_screenshot(self, actual, expected):
+        """
+        Validates `actual` contains `expected` value.
+         - Captures screenshot if failed
+        """
         self.sellib = BuiltIn().get_library_instance('SeleniumLibrary')
         isPassed = BuiltIn().run_keyword_and_return_status("BuiltIn.Should Contain", actual, expected)
         if not isPassed:
@@ -55,6 +60,10 @@ class SeleniumHelperLibrary(AttributeHelper, CheckboxHelper, ClickHelper,
     
     @keyword("Should Not Contain With Screenshot")
     def should_not_contain_with_screenshot(self, actual, expected):
+        """
+        Validates `actual` not contains `expected` value.
+         - Captures screenshot if failed
+        """
         self.sellib = BuiltIn().get_library_instance('SeleniumLibrary')
         isPassed = BuiltIn().run_keyword_and_return_status("BuiltIn.Should Not Contain", actual, expected)
         if not isPassed:
@@ -63,6 +72,10 @@ class SeleniumHelperLibrary(AttributeHelper, CheckboxHelper, ClickHelper,
     
     @keyword("Should Be Equal As Strings With Screenshot")
     def should_be_equal_as_strings_with_screenshot(self, actual, expected):
+        """
+        Validates `actual` equals `expected` value.
+         - Captures screenshot if failed
+        """
         self.sellib = BuiltIn().get_library_instance('SeleniumLibrary')
         isPassed = BuiltIn().run_keyword_and_return_status("BuiltIn.Should Be Equal As Strings", actual, expected)
         if not isPassed:
@@ -71,6 +84,9 @@ class SeleniumHelperLibrary(AttributeHelper, CheckboxHelper, ClickHelper,
 
     @keyword("Reload Webpage")
     def reload_webpage(self):
+        """
+        Performs reload in webpage and waits until dom get loaded
+        """
         self.sellib = BuiltIn().get_library_instance('SeleniumLibrary')
         self.sellib.reload_page()
         BuiltIn().run_keyword("SeleniumHelperLibrary.Wait Until DOM Loaded")
\ No newline at end of file
