@@ -11,7 +11,10 @@ class Util():
     @not_keyword
     def wait_for_element(self, instance, locator):
         instance.wait_until_page_contains_element(locator)
-        BuiltIn().run_keyword_and_ignore_error('SeleniumLibrary.Scroll Element Into View', locator)
+        try:
+            instance.scroll_element_into_view(locator)
+        except:
+            pass
     
     @not_keyword
     def wait_for_element_not_present(self, instance, locator):
